/*****************************************************************************
* aft_tdm_test_bri_loopback.c	AFT T1/E1: HDLC API Sample Code
*
* Author(s):	David Rokhvarg <davidr@sangoma.com>
*
* Copyright:	(c) 2003-2007 Sangoma Technologies Inc.
*
*		This program is free software; you can redistribute it and/or
*		modify it under the terms of the GNU General Public License
*		as published by the Free Software Foundation; either version
*		2 of the License, or (at your option) any later version.
* ============================================================================
*/


#include <stdlib.h>
#include <stdio.h>
#include <ctype.h>
#include <unistd.h>
#include <sys/time.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <linux/if_wanpipe.h>
#include <string.h>
#include <errno.h>
#include <fcntl.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <signal.h>
#include <linux/if.h>
#include <linux/wanpipe_defines.h>
#include <linux/wanpipe_cfg.h>
#include <linux/wanpipe.h>

#include <linux/wanrouter.h>		/* FE_DISCONNECTED, FE_CONNECTED */
#include <linux/sdla_front_end.h>	/* FE_STATUS_DECODE */

#include <libsangoma.h>
#include "lib_api.h"

int dev_fd;

/*
typedef struct wanpipe_tdm_api{
	wanpipe_tdm_api_cmd_t	wp_tdm_cmd;
	wanpipe_tdm_api_event_t wp_tdm_event;
}wanpipe_tdm_api_t;
*/
wanpipe_tdm_api_t tdm_api; 

int sangoma_tdm_cmd_exec(sng_fd_t fd, wanpipe_tdm_api_t *tdm_api)
{
	int err;
	
	printf("%s()\n", __FUNCTION__);

#if defined(WIN32)
	ggg
	err = tdmv_api_ioctl(fd, &tdm_api->wp_tdm_cmd);
#else
	err = ioctl(fd,SIOC_WANPIPE_TDM_API,&tdm_api->wp_tdm_cmd);
	if (err < 0){
		char tmp[50];
		sprintf(tmp,"TDM API: CMD: %i\n",tdm_api->wp_tdm_cmd.cmd);
		perror(tmp);
		return -1;
	}
#endif
	return err;
}

int sangoma_tdm_bri_loopback_control(sng_fd_t fd, wanpipe_tdm_api_t *tdm_api, 
				     unsigned char enable, unsigned char channel) 
{

	printf("%s()\n", __FUNCTION__);

	tdm_api->wp_tdm_cmd.cmd				= SIOC_WP_TDM_SET_EVENT;
	tdm_api->wp_tdm_cmd.event.wp_tdm_api_event_type = WP_TDMAPI_EVENT_BRI_CHAN_LOOPBACK;
	tdm_api->wp_tdm_cmd.event.wp_tdm_api_event_mode = enable;
	tdm_api->wp_tdm_cmd.event.channel		= channel;

	return sangoma_tdm_cmd_exec(fd, tdm_api);
}

/***************************************************************
 * Main:
 *
 *    o Make a socket connection to the driver.
 *    o Call handle_span_chan() to read the socket 
 *
 **************************************************************/

/* command line examples:
./aft_tdm_test_bri_loopback -c 1 -i 1 -r -bri_dchan1_loopback_on

./aft_tdm_test_bri_loopback -c 1 -i 1 -r -bri_dchan1_loopback_off

./aft_tdm_test_bri_loopback -c 1 -i 1 -r -bri_dchan2_loopback_on

./aft_tdm_test_bri_loopback -c 1 -i 1 -r -bri_dchan2_loopback_off
*/

int main(int argc, char* argv[])
{
	int proceed;

	proceed=init_args(argc,argv);
	if (proceed != WAN_TRUE){
		usage(argv[0]);
		return -1;
	}

	memset(&tdm_api,0,sizeof(tdm_api));
	
	printf("(1). HANDLING SPAN %i CHAN %i FD=%i\n", atoi(card_name),atoi(if_name),dev_fd);

	dev_fd = sangoma_open_tdmapi_span_chan(atoi(card_name),atoi(if_name));
	if( dev_fd < 0){
		printf("Failed to open span chan\n");
		exit (1);
	}
	printf("HANDLING SPAN %i CHAN %i FD=%i\n", atoi(card_name),atoi(if_name),dev_fd);

	switch(bri_bchan_loopback_cmd)
	{
	case 1:
		sangoma_tdm_bri_loopback_control(dev_fd, &tdm_api, WP_TDMAPI_EVENT_ENABLE, WAN_BRI_BCHAN1);
		break;
	case 2:
		sangoma_tdm_bri_loopback_control(dev_fd, &tdm_api, WP_TDMAPI_EVENT_DISABLE, WAN_BRI_BCHAN1);
		break;
	case 3:
		sangoma_tdm_bri_loopback_control(dev_fd, &tdm_api, WP_TDMAPI_EVENT_ENABLE, WAN_BRI_BCHAN2);
		break;
	case 4:
		sangoma_tdm_bri_loopback_control(dev_fd, &tdm_api, WP_TDMAPI_EVENT_DISABLE, WAN_BRI_BCHAN2);
		break;
	default:
		printf("Invalid bri command - %i\n", bri_bchan_loopback_cmd);
	}

	close(dev_fd);
	return 0;
};


