/*****************************************************************************
* aft_tdm_test_fe_status.c	AFT T1/E1: HDLC API Sample Code
*
* Author(s):	David Rokhvarg <davidr@sangoma.com>
*
* Copyright:	(c) 2003-2007 Sangoma Technologies Inc.
*
*		This program is free software; you can redistribute it and/or
*		modify it under the terms of the GNU General Public License
*		as published by the Free Software Foundation; either version
*		2 of the License, or (at your option) any later version.
* ============================================================================
*/


#include <stdlib.h>
#include <stdio.h>
#include <ctype.h>
#include <unistd.h>
#include <sys/time.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <linux/if_wanpipe.h>
#include <string.h>
#include <errno.h>
#include <fcntl.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <signal.h>
#include <linux/if.h>
#include <linux/wanpipe_defines.h>
#include <linux/wanpipe_cfg.h>
#include <linux/wanpipe.h>

#include <linux/wanrouter.h>		/* FE_DISCONNECTED, FE_CONNECTED */
#include <linux/sdla_front_end.h>	/* FE_STATUS_DECODE */

#include <libsangoma.h>
#include "lib_api.h"

/* Prototypes */
void sig_end(int sigid);

int dev_fd;
wanpipe_tdm_api_t tdm_api; 


/***************************************************************
 * Main:
 *
 *    o Make a socket connection to the driver.
 *    o Call handle_span_chan() to read the socket 
 *
 **************************************************************/

/* command line examples:

./aft_tdm_test_fe_status -c 1 -i 3 -r -activate_front_end

./aft_tdm_test_fe_status -c 1 -i 3 -r -deactivate_front_end

*/
int main(int argc, char* argv[])
{
	int proceed;
	unsigned char current_status, new_status;

	proceed=init_args(argc,argv);
	if (proceed != WAN_TRUE){
		usage(argv[0]);
		return -1;
	}

	signal(SIGINT,&sig_end);
	memset(&tdm_api,0,sizeof(tdm_api));
	
	printf("(1). HANDLING SPAN %i CHAN %i FD=%i\n", atoi(card_name),atoi(if_name),dev_fd);

	dev_fd = sangoma_open_tdmapi_span_chan(atoi(card_name),atoi(if_name));
	if( dev_fd < 0){
		printf("Failed to open span chan\n");
		exit (1);
	}
	printf("HANDLING SPAN %i CHAN %i FD=%i\n", atoi(card_name),atoi(if_name),dev_fd);
		
	//sangoma_tdm_set_codec(dev_fd,&tdm_api,WP_NONE);
	sangoma_get_full_cfg(dev_fd, &tdm_api);
		
	if(!sangoma_tdm_get_fe_status(dev_fd, &tdm_api, &current_status)){
		printf("current_status: %s\n", FE_STATUS_DECODE(current_status));
	}

	if(activate_front_end){
		new_status = FE_CONNECTED;
		printf("Activating Front End\n");
		sangoma_tdm_set_fe_status(dev_fd, &tdm_api, new_status);
	}else if(deactivate_front_end){
		new_status = FE_DISCONNECTED;
		printf("De-Activating Front End\n");
		sangoma_tdm_set_fe_status(dev_fd, &tdm_api, new_status);
	}else{
		printf("Invalid Front End command\n");
	}

	close(dev_fd);
	return 0;
};


void sig_end(int sigid)
{
	printf("Got Signal %i\n",sigid);

	if (dev_fd){
		close (dev_fd);
	}

	exit(1);
}

